@@ -1,34 +1,14 @@
 # This code modified from
 # https://github.com/atahk/bucky/blob/master/R/zzz.R (GPL 3.0)
 .onLoad <- function(libname, pkgname) {
-  if (suppressWarnings(requireNamespace("texreg", quietly=TRUE))) {
+  if (suppressWarnings(requireNamespace("texreg", quietly = TRUE))) {
     setGeneric("extract", function(model, ...) standardGeneric("extract"),
-               package = "texreg")
+      package = "texreg"
+    )
     setMethod("extract",
-              signature = className("lm_robust", pkgname),
-              definition = extract.lm_robust)
+      signature = className("lm_robust", pkgname),
+      definition = extract.lm_robust
+    )
   }
   invisible()
 }
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
