@@ -13,15 +13,15 @@ test_that("Horvitz-Thompson matches d-i-m under certain conditions", {
   dat$y <- ifelse(dat$z, dat$y1, dat$y0)
 
   expect_equal(
-    horvitz_thompson(
+    coef(horvitz_thompson(
       y ~ z,
       condition_prs = ps,
       data = dat
-    )$coefficients,
-    difference_in_means(
+    )),
+    coef(difference_in_means(
       y ~ z,
       data = dat
-    )$coefficients
+    ))
   )
 })
 
@@ -36,15 +36,34 @@ test_that("Horvitz-Thompson works in simple case", {
   ht_simp <- horvitz_thompson(
     y ~ z,
     data = dat,
-    declaration = simp_decl,
+    ra_declaration = simp_decl,
     return_condition_pr_mat = TRUE
   )
 
+  # Also with no SEs
+  ht_simp_no <- horvitz_thompson(
+    y ~ z,
+    data = dat,
+    ra_declaration = simp_decl,
+    return_condition_pr_mat = TRUE,
+    se_type = "none"
+  )
+
+  expect_equal(
+    ht_simp$estimate,
+    ht_simp_no$estimate
+  )
+
+  expect_equivalent(
+    tidy(ht_simp_no)[c("std.error", "p.value", "ci.lower", "ci.upper")],
+    rep(NA_real_, 4)
+  )
+
   # Works with constant effects assumption
   ht_const <- horvitz_thompson(
     y ~ z,
     data = dat,
-    declaration = simp_decl,
+    ra_declaration = simp_decl,
     se_type = "constant"
   )
 
@@ -54,7 +73,7 @@ test_that("Horvitz-Thompson works in simple case", {
     data = dat,
     condition1 = 1,
     condition2 = 0,
-    declaration = simp_decl,
+    ra_declaration = simp_decl,
     return_condition_pr_mat = TRUE
   )
 
@@ -66,13 +85,13 @@ test_that("Horvitz-Thompson works in simple case", {
       data = dat,
       condition1 = 0,
       condition2 = 2,
-      declaration = simp_decl
+      ra_declaration = simp_decl
     )
   )
 
   expect_equal(
-    tidy(ht_simp)[, c("coefficients", "se")],
-    tidy(ht_rev)[, c("coefficients", "se")] * c(-1, 1)
+    tidy(ht_simp)[, c("estimate", "std.error")],
+    tidy(ht_rev)[, c("estimate", "std.error")] * c(-1, 1)
   )
 
   # Simple designs needn't use condition matrix as joint prs are product of marginals
@@ -87,14 +106,27 @@ test_that("Horvitz-Thompson works in simple case", {
   dat$pr_comp <- 0.4
   # We can learn it! or you can tell us
   expect_equal(
-    horvitz_thompson(y ~ z_comp, data = dat, simple = FALSE),
-    horvitz_thompson(y ~ z_comp, data = dat, declaration = comp_decl)
+    ht_comp <- horvitz_thompson(y ~ z_comp, data = dat, simple = FALSE),
+    horvitz_thompson(y ~ z_comp, data = dat, ra_declaration = comp_decl)
   )
   expect_equal(
-    horvitz_thompson(y ~ z_comp, data = dat, simple = FALSE),
+    ht_comp,
     horvitz_thompson(y ~ z_comp, data = dat, simple = FALSE, condition_prs = pr_comp)
   )
 
+  # Also with no SEs
+  ht_comp_no <- horvitz_thompson(y ~ z_comp, data = dat, simple = FALSE, se_type = "none")
+
+  expect_equal(
+    ht_comp$estimate,
+    ht_comp_no$estimate
+  )
+
+  expect_equivalent(
+    tidy(ht_comp_no)[c("std.error", "p.value", "ci.lower", "ci.upper")],
+    rep(NA_real_, 4)
+  )
+
   # error if you pass wrong prs
   dat$pr_wrong <- dat$pr_comp
   dat$pr_wrong[1] <- 0.5
@@ -102,6 +134,30 @@ test_that("Horvitz-Thompson works in simple case", {
     horvitz_thompson(y ~ z_comp, data = dat, simple = FALSE, condition_prs = pr_wrong),
     "Treatment probabilities must be fixed for complete randomized designs"
   )
+
+  # Works without data frame!
+  ht_with <- with(
+    dat,
+    horvitz_thompson(y ~ z_comp, simple = FALSE, condition_prs = pr_comp)
+  )
+
+  pr_comp <- dat$pr_comp
+  y <- dat$y
+  z_comp <- dat$z_comp
+  ht_glob <- horvitz_thompson(y ~ z_comp, simple = FALSE, condition_prs = pr_comp)
+
+  expect_equal(
+    ht_with,
+    ht_glob
+  )
+
+  # with declaration
+  ht_nod <- horvitz_thompson(y ~ z_comp, ra_declaration = comp_decl)
+  ht_d <- horvitz_thompson(y ~ z_comp, data = dat, ra_declaration = comp_decl)
+  expect_equal(
+    tidy(ht_nod),
+    tidy(ht_d)
+  )
 })
 
 test_that("Horvitz-Thompson works with clustered data", {
@@ -116,13 +172,26 @@ test_that("Horvitz-Thompson works with clustered data", {
   dat$z <- randomizr::conduct_ra(clust_crs_decl)
 
   # Regular SE using Young's inequality
-  ht_crs_decl <- horvitz_thompson(y ~ z, data = dat, declaration = clust_crs_decl)
+  ht_crs_decl <- horvitz_thompson(y ~ z, data = dat, ra_declaration = clust_crs_decl)
 
   expect_equal(
     ht_crs_decl$df,
     NA
   )
 
+  # Also with no SEs
+  ht_crs_decl_no <- horvitz_thompson(y ~ z, data = dat, ra_declaration = clust_crs_decl, se_type = "none")
+
+  expect_equal(
+    ht_crs_decl$estimate,
+    ht_crs_decl_no$estimate
+  )
+
+  expect_equivalent(
+    tidy(ht_crs_decl_no)[c("std.error", "p.value", "ci.lower", "ci.upper")],
+    rep(NA_real_, 4)
+  )
+
   # Can infer probabilities as well
   expect_equal(
     ht_crs_decl,
@@ -131,7 +200,7 @@ test_that("Horvitz-Thompson works with clustered data", {
 
   # And constant effects error for non-simple designs
   expect_error(
-    horvitz_thompson(y ~ z, data = dat, declaration = clust_crs_decl, se_type = "constant"),
+    horvitz_thompson(y ~ z, data = dat, ra_declaration = clust_crs_decl, se_type = "constant"),
     "`se_type` = 'constant' only supported for simple random"
   )
 
@@ -145,7 +214,20 @@ test_that("Horvitz-Thompson works with clustered data", {
 
   # With declaration
   # Regular SE using Young's inequality
-  ht_srs_decl <- horvitz_thompson(y ~ z, data = dat, declaration = clust_srs_decl)
+  ht_srs_decl <- horvitz_thompson(y ~ z, data = dat, ra_declaration = clust_srs_decl)
+
+  # Also with no SEs
+  ht_srs_decl_no <- horvitz_thompson(y ~ z, data = dat, ra_declaration = clust_srs_decl, se_type = "none")
+
+  expect_equal(
+    ht_srs_decl$estimate,
+    ht_srs_decl_no$estimate
+  )
+
+  expect_equivalent(
+    tidy(ht_srs_decl_no)[c("std.error", "p.value", "ci.lower", "ci.upper")],
+    rep(NA_real_, 4)
+  )
 
   # Not the same because second doesn't know it's clustered!
   # Just passing mat
@@ -153,15 +235,31 @@ test_that("Horvitz-Thompson works with clustered data", {
   expect_is(
     all.equal(
       ht_srs_decl,
-      horvitz_thompson(y ~ z, data = dat, condition_pr_mat = clust_srs_mat)
+      ht_srs_nodecl <- horvitz_thompson(y ~ z, data = dat, condition_pr_mat = clust_srs_mat)
     ),
     "character"
   )
 
+  # Also with no SEs
+  ht_srs_nodecl_no <-  horvitz_thompson(y ~ z, data = dat, condition_pr_mat = clust_srs_mat, se_type = "none")
+
+  expect_equal(
+    ht_srs_nodecl$estimate,
+    ht_srs_nodecl_no$estimate
+  )
+
   # works if I also pass cluster
   expect_identical(
     ht_srs_decl,
-    horvitz_thompson(y ~ z, data = dat, clusters = cl, condition_pr_mat = clust_srs_mat)
+    ht_srs_cl <- horvitz_thompson(y ~ z, data = dat, clusters = cl, condition_pr_mat = clust_srs_mat)
+  )
+
+  # Also with no SEs
+  ht_srs_cl_no <- horvitz_thompson(y ~ z, data = dat, clusters = cl, condition_pr_mat = clust_srs_mat, se_type = "none")
+
+  expect_equal(
+    ht_srs_cl$estimate,
+    ht_srs_cl_no$estimate
   )
 
   # Can infer from number of treated clusters per block the treatment pr
@@ -174,7 +272,7 @@ test_that("Horvitz-Thompson works with clustered data", {
   blcl_ra <- randomizr::declare_ra(blocks = clbl_dat$bl, clusters = clbl_dat$cl_new, m = c(1, 2, 1))
   clbl_dat$z_clbl <- blcl_ra$ra_function()
   expect_equivalent(
-    horvitz_thompson(y ~ z_clbl, data = clbl_dat, declaration = blcl_ra),
+    horvitz_thompson(y ~ z_clbl, data = clbl_dat, ra_declaration = blcl_ra),
     horvitz_thompson(y ~ z_clbl, data = clbl_dat, blocks = bl, clusters = cl_new)
   )
 
@@ -182,14 +280,21 @@ test_that("Horvitz-Thompson works with clustered data", {
   dat$ps <- 0.4
   expect_identical(
     ht_srs_decl,
-    horvitz_thompson(y ~ z, data = dat, clusters = cl, condition_prs = ps)
+    ht_srs_prs <- horvitz_thompson(y ~ z, data = dat, clusters = cl, condition_prs = ps)
   )
 
+  # Also with no SEs
+  ht_srs_prs_no <- horvitz_thompson(y ~ z, data = dat, clusters = cl, condition_prs = ps, se_type = "none")
+
+  expect_equal(
+    ht_srs_prs$estimate,
+    ht_srs_prs_no$estimate
+  )
 
   # And constant effects
   # Only work for simple for now
   expect_error(
-    horvitz_thompson(y ~ z, data = dat, declaration = clust_srs_decl, se_type = "constant"),
+    horvitz_thompson(y ~ z, data = dat, ra_declaration = clust_srs_decl, se_type = "constant"),
     "`se_type` = 'constant' only supported for simple random designs at the moment"
   )
 
@@ -219,7 +324,6 @@ test_that("Horvitz-Thompson works with clustered data", {
   )
 })
 
-# TODO test missingness works as expected
 test_that("Horvitz-Thompson works with missingness", {
   n <- 40
   dat <- data.frame(
@@ -234,7 +338,7 @@ test_that("Horvitz-Thompson works with missingness", {
   missing_dat$y[1] <- NA
 
   expect_error(
-    horvitz_thompson(y ~ z, data = missing_dat, declaration = decl),
+    horvitz_thompson(y ~ z, data = missing_dat, ra_declaration = decl),
     NA
   )
 
@@ -266,7 +370,7 @@ test_that("Estimating Horvitz-Thompson can be done two ways with blocks", {
 
   # This creates estimates within blocks and then joins them together using the common
   # formula
-  ht_declare_bl <- horvitz_thompson(y ~ z, data = dat, declaration = bl_ra)
+  ht_declare_bl <- horvitz_thompson(y ~ z, data = dat, ra_declaration = bl_ra)
   # This estimates the treatment effect at once using only condition_pr_mat
   ht_condmat_bl <- horvitz_thompson(y ~ z, data = dat, condition_pr_mat = bl_pr_mat)
 
@@ -275,12 +379,25 @@ test_that("Estimating Horvitz-Thompson can be done two ways with blocks", {
     tidy(ht_condmat_bl)
   )
 
+  # Also with no SEs
+  ht_declare_bl_no <- horvitz_thompson(y ~ z, data = dat, ra_declaration = bl_ra, se_type = "none")
+  ht_condmat_bl_no <- horvitz_thompson(y ~ z, data = dat, condition_pr_mat = bl_pr_mat, se_type = "none")
+
+  expect_equal(
+    ht_declare_bl$estimate,
+    ht_declare_bl_no$estimate
+  )
+  expect_equal(
+    ht_condmat_bl$estimate,
+    ht_condmat_bl_no$estimate
+  )
+
   dat$mps <- rep(1:20, each = 2)
   mp_ra <- randomizr::declare_ra(blocks = dat$mps)
   dat$z <- randomizr::conduct_ra(mp_ra)
   mp_pr_mat <- declaration_to_condition_pr_mat(mp_ra)
 
-  ht_declare_mp <- horvitz_thompson(y ~ z, data = dat, declaration = mp_ra)
+  ht_declare_mp <- horvitz_thompson(y ~ z, data = dat, ra_declaration = mp_ra)
   # This estimates the treatment effect at once using only condition_pr_mat
   ht_condmat_mp <- horvitz_thompson(y ~ z, data = dat, condition_pr_mat = mp_pr_mat)
 
@@ -310,62 +427,31 @@ test_that("Horvitz-Thompson properly checks arguments and data", {
   )
 
   expect_error(
-    horvitz_thompson(y ~ z, data = dat, condition_prs = ps, declaration = decl),
-    "Cannot use `declaration` with any of"
+    horvitz_thompson(y ~ z, data = dat, condition_prs = ps, ra_declaration = decl),
+    "Cannot use `ra_declaration` with any of"
   )
 
   expect_error(
-    horvitz_thompson(y ~ z, data = dat, condition_pr_mat = declaration_to_condition_pr_mat(decl), declaration = decl),
-    "Cannot use `declaration` with any of"
+    horvitz_thompson(y ~ z, data = dat, condition_pr_mat = declaration_to_condition_pr_mat(decl), ra_declaration = decl),
+    "Cannot use `ra_declaration` with any of"
   )
 
   expect_error(
-    horvitz_thompson(y ~ z + x, data = dat, declaration = decl),
+    horvitz_thompson(y ~ z + x, data = dat, ra_declaration = decl),
     "must have only one variable on the right-hand side"
   )
 
   expect_error(
-    horvitz_thompson(y ~ z, data = dat, declaration = randomizr::declare_ra(N = n + 1, prob = 0.4)),
-    "N|declaration"
+    horvitz_thompson(y ~ z, data = dat, ra_declaration = randomizr::declare_ra(N = n + 1, prob = 0.4)),
+    "variable lengths differ"
   )
 
   ht_o <- horvitz_thompson(y ~ z, data = dat, ci = FALSE)
   expect_equivalent(
-    as.matrix(tidy(horvitz_thompson(y ~ z, data = dat, ci = FALSE))[, c("p", "ci_lower", "ci_upper")]),
+    as.matrix(tidy(horvitz_thompson(y ~ z, data = dat, ci = FALSE))[, c("p.value", "ci.lower", "ci.upper")]),
     matrix(NA, nrow = 1, ncol = 3)
   )
 
-  # Reserved variable names
-  dat[[".clusters_ddinternal"]] <- 1
-  expect_error(
-    horvitz_thompson(
-      y ~ z,
-      data = dat,
-      declaration = randomizr::declare_ra(clusters = dat$cl)
-    ),
-    ".clusters_ddinternal"
-  )
-
-  dat[[".blocks_ddinternal"]] <- 1
-  expect_error(
-    horvitz_thompson(
-      y ~ z,
-      data = dat,
-      declaration = randomizr::declare_ra(blocks = dat$bl)
-    ),
-    ".blocks_ddinternal"
-  )
-
-  dat[[".treatment_prob_ddinternal"]] <- 1
-  expect_error(
-    horvitz_thompson(
-      y ~ z,
-      data = dat,
-      declaration = randomizr::declare_ra(N = n)
-    ),
-    ".treatment_prob_ddinternal"
-  )
-
 
   # condition pr mat is the wrong size
   expect_error(
@@ -376,8 +462,6 @@ test_that("Horvitz-Thompson properly checks arguments and data", {
     ),
     "cleaning the data"
   )
-
-  # subset and condition_pr_mat checked
 })
 
 test_that("Works without variation in treatment", {
@@ -408,8 +492,8 @@ test_that("Works without variation in treatment", {
   )
 
 
-  expect_equivalent(ht_const_1$coefficients, mean(dat$y))
-  expect_equal(ht_const_1$se, 1 / (nrow(dat)) * sqrt(sum(dat$y ^ 2)))
+  expect_equivalent(coef(ht_const_1), mean(dat$y))
+  expect_equal(ht_const_1$std.error, 1 / (nrow(dat)) * sqrt(sum(dat$y ^ 2)))
 
 
   expect_equal(
@@ -423,8 +507,8 @@ test_that("Works without variation in treatment", {
     condition_prs = ps
   )
 
-  expect_equivalent(ht_const$coefficients, mean(dat$y / dat$ps))
-  expect_equal(ht_const$se, 1 / (nrow(dat)) * sqrt(sum((dat$y / dat$ps) ^ 2)))
+  expect_equivalent(coef(ht_const), mean(dat$y / dat$ps))
+  expect_equal(ht_const$std.error, 1 / (nrow(dat)) * sqrt(sum((dat$y / dat$ps) ^ 2)))
 
   ## Blocks and all are treated
   ht_block <- horvitz_thompson(
@@ -436,8 +520,8 @@ test_that("Works without variation in treatment", {
   )
 
   # with blocks SE is different because not simple any more
-  expect_equivalent(ht_block$coefficients, mean(dat$y / dat$ps))
-  # expect_equal(ht_block$se, 1/(nrow(dat)) * sqrt(sum((dat$y / dat$ps)^2)))
+  expect_equivalent(coef(ht_block), mean(dat$y / dat$ps))
+  # expect_equal(ht_block$std.error, 1/(nrow(dat)) * sqrt(sum((dat$y / dat$ps)^2)))
 
   ## Blocks and some are treated!
   dat$z_diff <- as.numeric(dat$bl <= 2)
@@ -459,7 +543,7 @@ test_that("Works without variation in treatment", {
     condition_prs = rep(0.5, nrow(dat))
   )
 
-  expect_identical(ht_zero$coefficient_name, "z0")
+  expect_identical(ht_zero$term, "z0")
 
   # Drop name if they specify the only treatment as condition1
   ht_rev <- horvitz_thompson(
@@ -470,12 +554,12 @@ test_that("Works without variation in treatment", {
     condition_prs = rep(0.5, nrow(dat))
   )
 
-  expect_identical(ht_rev$coefficient_name, "z")
+  expect_identical(ht_rev$term, "z")
 
   # This is only true because condition prs are 0.5
   expect_identical(
-    tidy(ht_zero)[c("coefficients", "se")],
-    tidy(ht_rev)[c("coefficients", "se")] * c(-1, 1)
+    tidy(ht_zero)[c("estimate", "std.error")],
+    tidy(ht_rev)[c("estimate", "std.error")] * c(-1, 1)
   )
 
   # Some weird specifications that hit unusual parts of the variance
@@ -493,7 +577,7 @@ test_that("Works without variation in treatment", {
   )
 })
 
-test_that("multi-valued treatments not allowed in declaration", {
+test_that("multi-valued treatments not allowed in ra_declaration", {
   dat <- data.frame(
     y = rnorm(20),
     ps = 0.4
@@ -503,8 +587,8 @@ test_that("multi-valued treatments not allowed in declaration", {
   dat$z <- randomizr::conduct_ra(decl_multi)
 
   expect_error(
-    horvitz_thompson(y ~ z, data = dat, declaration = decl_multi),
-    "Cannot use horvitz_thompson\\(\\) with a `declaration` with"
+    horvitz_thompson(y ~ z, data = dat, ra_declaration = decl_multi),
+    "Cannot use horvitz_thompson\\(\\) with a `ra_declaration` with"
   )
 
   # will work but you have to get the PRs right!
